from faker.factory import Factory
from faker.generator import Generator
from faker.proxy import Faker

VERSION = "9.5.3"

__all__ = ("Factory", "Generator", "Faker")
